#include <Adafruit_NeoPixel.h>
#include <IRremote.h>

// Pin definitions
#define LED_PIN_BOTTOM 6  // Pin for WS2812B LEDs on the bottom
#define LED_PIN_TOP    7  // Pin for WS2812B LEDs on the top
#define IR_RECEIVE_PIN 2  // Pin for IR receiver

// Number of LEDs in each strip
#define NUM_LEDS_BOTTOM 50 // Number of LEDs in the bottom strip
#define NUM_LEDS_TOP    40 // Number of LEDs in the top strip


Adafruit_NeoPixel stripBottom = Adafruit_NeoPixel(NUM_LEDS_BOTTOM, LED_PIN_BOTTOM, NEO_GRB + NEO_KHZ800);
Adafruit_NeoPixel stripTop = Adafruit_NeoPixel(NUM_LEDS_TOP, LED_PIN_TOP, NEO_GRB + NEO_KHZ800);

IRrecv irrecv(IR_RECEIVE_PIN);
decode_results results;

// Define IR values
#define IR_ON           0xF7C03F
#define IR_OFF          0xF740BF
#define IR_BRIGHT_DOWN  0xF7807F
#define IR_BRIGHT_UP    0xF700FF
#define IR_WHITE        0xF7E01F
#define IR_BLUE         0xF7609F
#define IR_GREEN        0xF7A05F
#define IR_RED          0xF720DF
#define IR_ORANGE_RED   0xF710EF
#define IR_ORANGE       0xF730CF
#define IR_LIGHT_ORANGE 0xF708F7
#define IR_YELLOW       0xF728D7
#define IR_LIGHT_GREEN  0xF7906F
#define IR_CYAN         0xF7B04F
#define IR_LIGHT_BLUE   0xF78877
#define IR_GREEN_BLUE   0xF7A857
#define IR_DARK_BLUE    0xF750AF
#define IR_DARK_PURPLE  0xF7708F
#define IR_PURPLE       0xF748B7
#define IR_PINK         0xF76897

// Define colors (RGB values)
#define COLOR_WHITE stripBottom.Color(255, 255, 255)
#define COLOR_BLUE stripBottom.Color(0, 0, 255)
#define COLOR_GREEN stripBottom.Color(0, 255, 0)
#define COLOR_RED stripBottom.Color(255, 0, 0)
#define COLOR_ORANGE_RED stripBottom.Color(255, 9, 0)
#define COLOR_ORANGE stripBottom.Color(255, 25, 0)
#define COLOR_LIGHT_ORANGE stripBottom.Color(255, 40, 0)
#define COLOR_YELLOW stripBottom.Color(255, 90, 0)
#define COLOR_LIGHT_GREEN stripBottom.Color(93, 255, 0)
#define COLOR_CYAN stripBottom.Color(0, 255, 55)
#define COLOR_LIGHT_BLUE stripBottom.Color(0, 255, 85)
#define COLOR_GREEN_BLUE stripBottom.Color(0, 255, 65)
#define COLOR_DARK_BLUE stripBottom.Color(0, 95, 255)
#define COLOR_DARK_PURPLE stripBottom.Color(255, 0, 255)
#define COLOR_PURPLE stripBottom.Color(255, 20, 255)
#define COLOR_PINK stripBottom.Color(255, 0, 100)

// Variables for brightness control
int brightness = 125;

void setup() {

  stripBottom.begin();
  stripBottom.setBrightness(brightness);
  stripBottom.show();

  stripTop.begin();
  stripTop.setBrightness(brightness);
  stripTop.show(); 

  // Initialize IR receiver
  irrecv.enableIRIn();
  
  Serial.begin(9600);  // Serial for debugging
}

void loop() {
  if (irrecv.decode(&results)) {
    Serial.println(results.value, HEX);  

    uint32_t color = stripBottom.Color(0, 0, 0); // Default color (off)

    switch (results.value) {
      case IR_ON:
        color = COLOR_WHITE;
        break;
      case IR_OFF:
        color = stripBottom.Color(0, 0, 0); // Turn off LEDs (black color)
        break;
      case IR_WHITE:
        color = COLOR_WHITE;
        break;
      case IR_BLUE:
        color = COLOR_BLUE;
        break;
      case IR_GREEN:
        color = COLOR_GREEN;
        break;
      case IR_RED:
        color = COLOR_RED;
        break;
      case IR_ORANGE_RED:
        color = COLOR_ORANGE_RED;
        break;
      case IR_ORANGE:
        color = COLOR_ORANGE;
        break;
      case IR_LIGHT_ORANGE:
        color = COLOR_LIGHT_ORANGE;
        break;
      case IR_YELLOW:
        color = COLOR_YELLOW;
        break;
      case IR_LIGHT_GREEN:
        color = COLOR_LIGHT_GREEN;
        break;
      case IR_CYAN:
        color = COLOR_CYAN;
        break;
      case IR_LIGHT_BLUE:
        color = COLOR_LIGHT_BLUE;
        break;
      case IR_GREEN_BLUE:
        color = COLOR_GREEN_BLUE;
        break;
      case IR_DARK_BLUE:
        color = COLOR_DARK_BLUE;
        break;
      case IR_DARK_PURPLE:
        color = COLOR_DARK_PURPLE;
        break;
      case IR_PURPLE:
        color = COLOR_PURPLE;
        break;
      case IR_PINK:
        color = COLOR_PINK;
        break;
    }

  
    setStripColor(stripBottom, color);
    setStripColor(stripTop, color);

    irrecv.resume();
  }
}

void setStripColor(Adafruit_NeoPixel &strip, uint32_t color) {
  for (int i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, color);
  }
  strip.show();
}
